import  { 
  select,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  schemeSpectral
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';

const svg = select("svg");
const g = svg.append("g");
svg.call(zoom().on('zoom',() => {
  g.attr('transform', event.transform);
})); 
const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);
g.append("path")
  		.attr("d", pathGenerator({type : "Sphere"}))
			.attr("class", "sphere");

const colorScale = scaleOrdinal();
const basis = "economy"
const colorValue = d => d.properties[basis];

loadAndProcessData()
  .then( countries => {
  	colorScale
      .domain(countries.features.map(colorValue))
      .domain(colorScale.domain().sort())
      .range(schemeSpectral[colorScale.domain().length].reverse());
  
  	svg.append("g")
				.attr("transform", `translate(30, 250)`)
      .call(colorLegend, { 
        colorScale,
        circleRadius: 7,
        spacing: 20,
        textOffset: 15,
      	backgroundWidth: 230
      });
  
		g.selectAll("path")
      .data(countries.features)
      .enter().append("path")
        .attr("class", "country")
        .attr("d", pathGenerator)
        .attr("fill", d => colorScale(colorValue(d)))
      .append("title")
        .text(d => d.properties.name + ": " + colorValue(d).slice(3));
	});